@@ -1,7 +1,7 @@
 import asyncio
 
-from deepfos_ipc_protocol.const import MESSAGE_PROTOCOL, HEADER_PROTOCOL, DETAILLIST_PROTOCOL
-from deepfos_ipc_protocol.utils import (
+from const import MESSAGE_PROTOCOL, HEADER_PROTOCOL, DETAILLIST_PROTOCOL
+from utils import (
     judge_data_format,
     to_msg_protocol,
     to_header_protocol,
@@ -14,18 +14,19 @@ logger = logging.getLogger(__name__)
 
 
 class ClientProtocol(asyncio.Protocol):
-    def __init__(self, future, loop):
-        self.future = future
-        self.loop = loop
+
+    def __init__(self, ins):
+        self.ins = ins
 
     def connection_made(self, transport):
         logger.info("Connection made")
         self.transport = transport
 
     def data_received(self, data):
+        if data == b"end":
+            self.transport.close()
         if data:
-            self.future.set_result(True)
-            self.future = self.loop.create_future()
+            self.ins.future.set_result(data)
         logger.info("Data received: {!r}".format(data.decode()))
 
     def connection_lost(self, error):
@@ -36,18 +37,17 @@ class ClientProtocol(asyncio.Protocol):
 
 
 class EchoClientProtocol:
+    
+    transport = None
 
-    def __new__(cls, *args, **kwargs):
+    def __new__(cls, path, loop):
         if not hasattr(cls, '_instance'):
             cls._instance = super().__new__(cls)
         return cls._instance
 
-    def __init__(self, path: str):
+    def __init__(self, path: str, loop):
         self.path = path
-        self.transport = None
-        self.loop = asyncio.new_event_loop()
-        asyncio.set_event_loop(self.loop)
-        self.future = self.loop.create_future()
+        self.loop = loop
 
     def _processing_data(self, mtype: str, data):
         '''将传入的数据转为服务端可读取的数据'''
@@ -61,28 +61,25 @@ class EchoClientProtocol:
             raise ValueError("Unsupported message type: {}".format(mtype))
         return buf
 
-    async def _create_conn(self):
+    async def create_conn(self):
         '''建立和服务端的连接'''
-        if not self.transport:
+        if not self.transport or self.transport.is_closing():
             transport, protocol = await self.loop.create_unix_connection(
-                lambda: ClientProtocol(self.future, self.loop), self.path
+                lambda: ClientProtocol(self), self.path
             )
             self.transport = transport
 
-    async def _send_msg(self, mtype, message):
+    async def send_msg(self, mtype, message):
         '''向服务端发送数据'''
-        await self._create_conn()
+        judge_data_format(mtype, message)
+        # await self.create_conn()
+        self.future = self.loop.create_future()
         data = self._processing_data(mtype, message)
         self.transport.write(data)
+        return await self.future
+
+    async def close(self):
+        self.future = self.loop.create_future()
+        self.transport.write(b'end')
         await self.future
-
-    def send_msg(self, mtype, message):
-        judge_data_format(mtype, message)
-        self.loop.run_until_complete(self._send_msg(mtype, message))
-
-    def close(self):
-        try:
-            self.transport.write(b'end')
-        finally:
-            self.transport.close()
-            self.loop.stop()
+        self.transport.close()
