@@ -55,6 +55,15 @@ SUBTASKUPDATE_REVERSE_FIELD_MAP = {
 # [{'key':'xxx','name':'xxxx'},....]
 # elements的每一个成员的value(Field类型)的key取值情况为：'key'、'name'。
 SUBTASKINIT_META = [0x49, "I"]
+SUB_KEY_INDEX = b"\x01\x00"
+SUB_NAME_INDEX = b"\x02\x00"
+SUBTASKINIT_FIELD_MAP = {
+    SUB_KEY_INDEX: "key",
+    SUB_NAME_INDEX: "name",
+}
+SUBTASKINIT_REVERSE_FIELD_MAP = {
+    v: k for k, v in SUBTASKINIT_FIELD_MAP.items()
+}
 
 HEADER_PROTOCOL = sum([HEADER_META, SUBTASKUPDATE_META], [])
 MESSAGE_PROTOCOL = sum([STDERR_META, STDOUT_META], [])
