@@ -1,13 +1,13 @@
 import asyncio
 
 from inspect import isfunction
-from deepfos_ipc_protocol.utils import (
+from utils import (
     resolve_header_protocol,
     resolve_msg_protocol,
     resolve_detaillist_protocol,
     logging
 )
-from deepfos_ipc_protocol.const import (
+from const import (
     HEADER_PROTOCOL,
     MESSAGE_PROTOCOL,
     DETAILLIST_PROTOCOL
@@ -32,6 +32,7 @@ class ServerProtocol(asyncio.Protocol):
 
     def data_received(self, data):
         if data == b"end":
+            self.transport.write(b"end")
             self.transport.close()
             return
         mtype = data[0]
@@ -48,11 +49,7 @@ class ServerProtocol(asyncio.Protocol):
             else:
                 logger.error(f"Unsupported mtype: {chr(mtype)}")
                 raise ValueError(f"Unsupported mtype: {chr(mtype)}")
-            if isinstance(self.ins, type) and hasattr(self.ins, self.kwargs.get("func")):
-                func = getattr(self.ins, self.kwargs["func"])
-                del self.kwargs["func"]
-                func(self.ins, chr(mtype), self.data, **self.kwargs)
-            elif isfunction(self.ins):
+            if self.ins:
                 self.ins(chr(mtype), self.data, **self.kwargs)
             self.transport.write(b"success")
         except Exception as e:
@@ -60,7 +57,6 @@ class ServerProtocol(asyncio.Protocol):
             self.transport.write(e.__str__().encode("utf8"))
 
     def connection_lost(self, error):
-        self.transport.close()
         if error:
             logger.error('SERVER ERROR: {}'.format(error))
         else:
@@ -77,18 +73,30 @@ class EchoServer:
         self.path = path
         self.ins = ins
         self.kwargs = kwargs
+        self.func = self.get_func()
+
+    def get_func(self):
+        if isinstance(self.ins, type) and hasattr(self.ins, self.kwargs.get("func")):
+            func = getattr(self.ins, self.kwargs["func"])
+            del self.kwargs["func"]
+            setattr(self.ins, "func", func)
+            return self.ins().func
+        elif isfunction(self.ins):
+            return self.ins
+        else:
+            return None
 
     async def task(self):
         loop = asyncio.get_running_loop()
         server = await loop.create_unix_server(
-            lambda: ServerProtocol(self.ins, **self.kwargs), self.path,
+            lambda: ServerProtocol(self.func, **self.kwargs), self.path,
         )
         async with server:
             await server.serve_forever()
 
     def run(self):
         asyncio.run(self.task())
-
+        
 
 m = EchoServer("../unix_sock.sock")
-m.run()
+m.run()
\ No newline at end of file
