@@ -1,9 +1,12 @@
 from typing import Dict
-from deepfos_ipc_protocol.const import (
+from const import (
     HEADER_REVERSE_FIELD_MAP,
     SUBTASKUPDATE_META,
     SUBTASKUPDATE_FIELD_MAP,
     SUBTASKUPDATE_REVERSE_FIELD_MAP,
+    SUBTASKINIT_META,
+    SUBTASKINIT_FIELD_MAP,
+    SUBTASKINIT_REVERSE_FIELD_MAP,
     HEADER_META,
     HEADER_FIELD_MAP,
     MESSAGE_PROTOCOL,
@@ -66,6 +69,10 @@ def get_filed_map(mtype, reverse: bool) -> Dict[str, str]:
         if reverse:
             return SUBTASKUPDATE_REVERSE_FIELD_MAP
         return SUBTASKUPDATE_FIELD_MAP
+    elif mtype in SUBTASKINIT_META:
+        if reverse:
+            return SUBTASKINIT_REVERSE_FIELD_MAP
+        return SUBTASKINIT_FIELD_MAP
     else:
         logger.error(f"Unknown meta type: {mtype}")
         raise ValueError("Unknown meta type: {}".format(mtype))
@@ -158,21 +165,21 @@ def to_detaillist_protocol(mtype: str, value_list: list) -> bytes:
     num_elements = int_to_int32(len(value_list))
     detail_buf = b""
     for index, value in enumerate(value_list):
-        detail_buf += _to_detail_protocol(index, value)
+        detail_buf += _to_detail_protocol(mtype, index, value)
     mlen = int_to_int32(len(detail_buf))
     return _mtype + mlen + num_elements + detail_buf
 
 
-def _to_detail_protocol(index, d: Dict[str, str]) -> bytes:
+def _to_detail_protocol(mtype, index, d: Dict[str, str]) -> bytes:
     index_buf = int_to_int32(index)
     num_fields = int_to_int32(len(d))
-    buf_fields = _to_filed_protocol("U", d)
+    buf_fields = _to_filed_protocol(mtype, d)
     return index_buf + num_fields + buf_fields
 
 
 def resolve_detaillist_protocol(buf: bytes) -> list:
     ptr = 0
-    field_map = get_filed_map("U", False)
+    field_map = get_filed_map("I", False)
     mlen = read_int32(buf[ptr + 1: ptr + 5])
     num_elements = read_int32(buf[5: 9])
     detail_buf = buf[9: mlen + 9]
